@@ -13,15 +13,15 @@ import datetime as d
 
 
 class data_process:
-    def __init__(self, dataset_name):
+    def __init__(self, dir, dataset_name):
         if dataset_name == 'mnist':
             apply_transform = transforms.Compose([
                 transforms.ToTensor(),
                 transforms.Normalize((0.1307,), (0.3081,))])
             self.train_dataset = datasets.MNIST(
-                './data/'+dataset_name, train=True, download=True, transform=apply_transform)
+                dir, train=True, download=True, transform=apply_transform)
             self.test_dataset = datasets.MNIST(
-                './data/'+dataset_name, train=False, download=True, transform=apply_transform)
+                dir, train=False, download=True, transform=apply_transform)
         elif dataset_name == 'cifar10':
             transform = transforms.Compose([transforms.ToTensor(),transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
             self.train_dataset = datasets.CIFAR10(root='./data/'+dataset_name, train=True,download=True, transform=transform)
